summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorLinus Groh <mail@linusgroh.de>2022-11-09 22:37:07 +0000
committerLinus Groh <mail@linusgroh.de>2022-11-09 22:38:03 +0000
commita2a4ad3b9dfa77cce8d27872631ad3928f918306 (patch)
tree57c54a4109a90cc3ce6ed79651ed00179ca1b966
parent00326a63ed6b07acfe437ccae1253b593463c75b (diff)
downloadserenity-a2a4ad3b9dfa77cce8d27872631ad3928f918306.zip
LibWeb: Fix typo in BodyInitOrReadableBytes type alias
-rw-r--r--Userland/Libraries/LibWeb/Fetch/BodyInit.cpp4
-rw-r--r--Userland/Libraries/LibWeb/Fetch/BodyInit.h6
-rw-r--r--Userland/Libraries/LibWeb/Fetch/Fetching/Fetching.cpp12
3 files changed, 11 insertions, 11 deletions
diff --git a/Userland/Libraries/LibWeb/Fetch/BodyInit.cpp b/Userland/Libraries/LibWeb/Fetch/BodyInit.cpp
index 18d318ba46..7e18360a43 100644
--- a/Userland/Libraries/LibWeb/Fetch/BodyInit.cpp
+++ b/Userland/Libraries/LibWeb/Fetch/BodyInit.cpp
@@ -14,7 +14,7 @@
namespace Web::Fetch {
// https://fetch.spec.whatwg.org/#bodyinit-safely-extract
-WebIDL::ExceptionOr<Infrastructure::BodyWithType> safely_extract_body(JS::Realm& realm, BodyInitOrReadbleBytes const& object)
+WebIDL::ExceptionOr<Infrastructure::BodyWithType> safely_extract_body(JS::Realm& realm, BodyInitOrReadableBytes const& object)
{
// 1. If object is a ReadableStream object, then:
if (auto const* stream = object.get_pointer<JS::Handle<Streams::ReadableStream>>()) {
@@ -27,7 +27,7 @@ WebIDL::ExceptionOr<Infrastructure::BodyWithType> safely_extract_body(JS::Realm&
}
// https://fetch.spec.whatwg.org/#concept-bodyinit-extract
-WebIDL::ExceptionOr<Infrastructure::BodyWithType> extract_body(JS::Realm& realm, BodyInitOrReadbleBytes const& object, bool keepalive)
+WebIDL::ExceptionOr<Infrastructure::BodyWithType> extract_body(JS::Realm& realm, BodyInitOrReadableBytes const& object, bool keepalive)
{
// 1. Let stream be null.
JS::GCPtr<Streams::ReadableStream> stream;
diff --git a/Userland/Libraries/LibWeb/Fetch/BodyInit.h b/Userland/Libraries/LibWeb/Fetch/BodyInit.h
index 1a14dcae94..6b009f88a1 100644
--- a/Userland/Libraries/LibWeb/Fetch/BodyInit.h
+++ b/Userland/Libraries/LibWeb/Fetch/BodyInit.h
@@ -19,8 +19,8 @@ using XMLHttpRequestBodyInit = Variant<JS::Handle<FileAPI::Blob>, JS::Handle<JS:
// https://fetch.spec.whatwg.org/#bodyinit
using BodyInit = Variant<JS::Handle<Streams::ReadableStream>, JS::Handle<FileAPI::Blob>, JS::Handle<JS::Object>, JS::Handle<URL::URLSearchParams>, String>;
-using BodyInitOrReadbleBytes = Variant<JS::Handle<Streams::ReadableStream>, JS::Handle<FileAPI::Blob>, JS::Handle<JS::Object>, JS::Handle<URL::URLSearchParams>, String, ReadonlyBytes>;
-WebIDL::ExceptionOr<Infrastructure::BodyWithType> safely_extract_body(JS::Realm&, BodyInitOrReadbleBytes const&);
-WebIDL::ExceptionOr<Infrastructure::BodyWithType> extract_body(JS::Realm&, BodyInitOrReadbleBytes const&, bool keepalive = false);
+using BodyInitOrReadableBytes = Variant<JS::Handle<Streams::ReadableStream>, JS::Handle<FileAPI::Blob>, JS::Handle<JS::Object>, JS::Handle<URL::URLSearchParams>, String, ReadonlyBytes>;
+WebIDL::ExceptionOr<Infrastructure::BodyWithType> safely_extract_body(JS::Realm&, BodyInitOrReadableBytes const&);
+WebIDL::ExceptionOr<Infrastructure::BodyWithType> extract_body(JS::Realm&, BodyInitOrReadableBytes const&, bool keepalive = false);
}
diff --git a/Userland/Libraries/LibWeb/Fetch/Fetching/Fetching.cpp b/Userland/Libraries/LibWeb/Fetch/Fetching/Fetching.cpp
index 3c31b5238c..127e27c195 100644
--- a/Userland/Libraries/LibWeb/Fetch/Fetching/Fetching.cpp
+++ b/Userland/Libraries/LibWeb/Fetch/Fetching/Fetching.cpp
@@ -1018,10 +1018,10 @@ WebIDL::ExceptionOr<JS::NonnullGCPtr<PendingResponse>> http_redirect_fetch(JS::R
// NOTE: request’s body’s source’s nullity has already been checked.
if (!request->body().has<Empty>()) {
auto const& source = request->body().get<Infrastructure::Body>().source();
// NOTE: BodyInitOrReadbleBytes is a superset of Body::SourceType
auto converted_source = source.has<ByteBuffer>()
- ? BodyInitOrReadbleBytes { source.get<ByteBuffer>() }
- : BodyInitOrReadbleBytes { source.get<JS::Handle<FileAPI::Blob>>() };
+ ? BodyInitOrReadableBytes { source.get<ByteBuffer>() }
+ : BodyInitOrReadableBytes { source.get<JS::Handle<FileAPI::Blob>>() };
auto [body, _] = TRY(safely_extract_body(realm, converted_source));
request->set_body(move(body));
}
@@ -1432,10 +1432,10 @@ WebIDL::ExceptionOr<JS::NonnullGCPtr<PendingResponse>> http_network_or_cache_fet
// 2. Set request’s body to the body of the result of safely extracting request’s body’s source.
auto const& source = request->body().get<Infrastructure::Body>().source();
// NOTE: BodyInitOrReadbleBytes is a superset of Body::SourceType
auto converted_source = source.has<ByteBuffer>()
- ? BodyInitOrReadbleBytes { source.get<ByteBuffer>() }
- : BodyInitOrReadbleBytes { source.get<JS::Handle<FileAPI::Blob>>() };
+ ? BodyInitOrReadableBytes { source.get<ByteBuffer>() }
+ : BodyInitOrReadableBytes { source.get<JS::Handle<FileAPI::Blob>>() };
auto [body, _] = TRY_OR_IGNORE(safely_extract_body(realm, converted_source));
request->set_body(move(body));
}
@@ -1018,10 +1018,10 @@ WebIDL::ExceptionOr<JS::NonnullGCPtr<PendingResponse>> http_redirect_fetch(JS::R
if (!request->body().has<Empty>()) {
auto const& source = request->body().get<Infrastructure::Body>().source();
- // NOTE: BodyInitOrReadbleBytes is a superset of Body::SourceType
+ // NOTE: BodyInitOrReadableBytes is a superset of Body::SourceType
auto converted_source = source.has<ByteBuffer>()
@@ -1432,10 +1432,10 @@ WebIDL::ExceptionOr<JS::NonnullGCPtr<PendingResponse>> http_network_or_cache_fet
// 2. Set request’s body to the body of the result of safely extracting request’s body’s source.
auto const& source = request->body().get<Infrastructure::Body>().source();
- // NOTE: BodyInitOrReadbleBytes is a superset of Body::SourceType
+ // NOTE: BodyInitOrReadableBytes is a superset of Body::SourceType
auto converted_source = source.has<ByteBuffer>()